@@ -11,7 +11,7 @@ from celery.states import FAILURE, PROPAGATE_STATES, REJECTED, RETRY, REVOKED, S
 
 from .code_highlighter import traceback_highlighter_factory, typed_code
 from .display_modes import ModeTask, ModeWorker, find_mode
-from ..protos.clearly_pb2 import CaptureRequest, Empty, FilterTasksRequest, FilterWorkersRequest, \
+from ..protos.clearly_pb2 import CaptureRequest, FilterTasksRequest, FilterWorkersRequest, Null, \
     PatternFilter, TaskMessage, WorkerMessage
 from ..protos.clearly_pb2_grpc import ClearlyServerStub
 from ..utils.colors import Colors
@@ -80,7 +80,7 @@ class ClearlyClient:
         what you need, and don't worry as the Clearly Server will still seamlessly
         handle all tasks updates.
 
-        Currently you can filter tasks by name, uuid, routing key or state.
+        Currently, you can filter tasks by name, uuid, routing key or state.
         Insert an '!' in the first position to select those that do not match criteria.
 
         This runs in the foreground. Press CTRL+C at any time to stop it.
@@ -107,7 +107,7 @@ class ClearlyClient:
         what you need, and don't worry as the Clearly Server will still seamlessly
         handle all tasks and workers updates.
 
-        Currently you can filter workers by hostname.
+        Currently, you can filter workers by hostname.
         Insert an '!' in the first position to select those that do not match criteria.
 
         This runs in the foreground. Press CTRL+C at any time to stop it.
@@ -169,33 +169,13 @@ class ClearlyClient:
         except KeyboardInterrupt:  # pragma: no cover
             pass
 
-    @set_user_friendly_errors
-    def metrics(self) -> None:
-        """List some metrics about the capturing system itself, which of course
-        reflects the actual celery pool being monitored.
-
-        Shows:
-            Tasks processed: number of tasks processed, including retries
-            Events processed: number of events processed, including workers and heartbeats
-            Tasks stored: number of unique tasks processed
-            Workers stored: number of unique workers seen
-
-        """
-        stats = self._stub.get_stats(Empty())
-        print(Colors.DIM('Processed:'),
-              '\ttasks', Colors.RED(stats.task_count),
-              '\tevents', Colors.RED(stats.event_count))
-        print(Colors.DIM('Stored:'),
-              '\ttasks', Colors.RED(stats.len_tasks),
-              '\tworkers', Colors.RED(stats.len_workers))
-
     @set_user_friendly_errors
     def tasks(self, tasks: Optional[str] = None, mode: Union[None, int, ModeTask] = None,
               limit: Optional[int] = None, reverse: bool = True) -> None:
         """Fetch current data from past tasks.
 
         Note that the `limit` field is just a hint, it may not be accurate.
-        Even the total number of tasks fetched may be slightly different than
+        Also, the total number of tasks fetched may be slightly different from
         the server `max_tasks` setting.
 
         Args:
@@ -252,16 +232,35 @@ class ClearlyClient:
     @set_user_friendly_errors
     def seen_tasks(self) -> None:
         """Fetch a list of seen task types."""
-        task_types = self._stub.seen_tasks(Empty()).task_types
+        task_types = self._stub.seen_tasks(Null()).task_types
         for i, task_type in enumerate(task_types, 1):
             print(Colors.DIM(i), Colors.BLUE(task_type))
 
     @set_user_friendly_errors
-    def reset(self) -> None:
-        """Reset all captured tasks."""
-        self._stub.reset_tasks(Empty())
+    def reset_tasks(self) -> None:
+        """Reset stored tasks."""
+        self._stub.reset_tasks(Null())
         print(Colors.BLUE('Ok'))
 
+    @set_user_friendly_errors
+    def metrics(self) -> None:
+        """List some metrics about the celery cluster and Clearly itself.
+
+        Shows:
+            Tasks processed: actual number of tasks processed, including retries
+            Events processed: total number of events processed
+            Tasks stored: number of currently stored tasks
+            Workers stored: number of workers seen, including offline
+
+        """
+        stats = self._stub.get_metrics(Null())
+        print(Colors.DIM('Processed:'),
+              '\ttasks', Colors.RED(stats.task_count),
+              '\tevents', Colors.RED(stats.event_count))
+        print(Colors.DIM('Stored:'),
+              '\ttasks', Colors.RED(stats.len_tasks),
+              '\tworkers', Colors.RED(stats.len_workers))
+
     def _get_display_modes(self, modes: Union[None, int, ModeTask, ModeWorker, Tuple] = None) \
             -> Modes:
         if not isinstance(modes, tuple):
